# Sccuot NG Manual
Welcome to **Sccuot NG** - the **N**ext **G**eneration version of the **Statistical computations component and usage overview tool**.

This manual will give you an overview of what Sccuot NG is, which features it offers and how to configure and use it.

## What is Sccuot NG?
Sccuot NG is a tool to collect and display usage and resource information of an ownCloud 10 instance. It can be used to gather various statistics in so-called *snapshots*, including:
  * Metrics like number of users, files and used storage
  * File types distribution
  * Used storage amount and quota per user
  * And more!

The Sccuot NG graphical interface allows you to browse through these various statistics, while snapshots can be taken automatically or manually through this interface or via command-line using the `occ` command.

### Snapshots
When created, a _snapshot_ captures and stores various statistics from the current state of your ownCloud instance that you can then browse in the graphical interface of Sccuot NG.

This not only gives you a good overview of the current status of your instance, but also lets you easily evaluate how your instance has evolved over time! This means that Sccuot NG also acts as a time machine that allows you to take a peek into various time points of the past of your instance.

## Requirements
Sccuot NG actually has no special requirements except for running on an ownCloud 10 instance! It has been tested with ownCloud 10.9 and 10.10, but any other minor version (10.xx) should work just as well.

_Note: If you've used the predecessor of Sccuot NG - Sccuot -, you'll notice that Sccuot NG doesn't use an external client application anymore, thus completely removing all of its dependencies and specific requirements!_

## Installation
There are no special installation steps necessary to run Sccuot NG. We highly recommend to install the app through the ownCloud Marketplace.

If you want to use the source code version from our [Git repository](https://zivgitlab.uni-muenster.de/wwu-it/sccuot-ng), it is easiest to clone the repo directly into ownCloud's `apps-external` directory. **Note that you need to name the target directory `sccuot_ng` instead of `sccuot-ng`!** Here is an example `git` call to clone the repository:
```
git clone https://zivgitlab.uni-muenster.de/wwu-it/sccuot-ng sccuot_ng
```

Then, all you need to do is to manually enable the app in the ownCloud settings.

### Managing access to the app
By default, everyone will be able to access the app after it has been installed. However, any non-administrative user will only get a 'read-only' view which allows him to browse through all snapshots but nothing else.

If you want to completely disable access to the app for certain user groups, you need to use the `Enable only for specific groups` option in ownCloud's _Apps_ settings.

## Usage
Sccuot NG is used through its comfortable user interface which allows you take take and manage snapshots and browse the various statistics. Below is a brief overview of all interface sections, as well as all supported `occ` commands. Sccuot NG is extremely easy to use and user-friendly, but if you miss anything here, let us know! 

### Viewing statistics
The **Statistics: Statistics & Metrics** page lets you view all statistics and metrics you previously captured in snapshots.

You can select the snapshot to display using the top-left drop-down list. Next to this list follow the various statistics types you can browse:
  * **Metrics** An overview of numerous figures, including the total number of users, their overall activity, used storage, created shares, and more.
  * **File types** This diagram displays the total number of files grouped by various file types (e.g., documents and images), as well as their used storage. The groups to capture and their corresponding file endings can be freely configured in Sccuot NG's snapshot settings (see below).
  * **Users storage** This histogram shows how many users have used up to a certain amount of storage. To filter this display, minimum and maximum limits can be defined; users that use less than the minimum or more than the maximum amount specified will not be taken into account. It is also possible to set the number of histogram bins using the drop-down list on the right.
  * **Users quota** This histograms shows how many users have used up to a certain amount of their storage quota (users that do not have a quota assigned are ignored). The number of histogram bins can be set using the drop-down list on the right.

For all statistics and diagrams, the file size unit (bytes, kilobytes, and so on) can be changed using the top-right drop-down list.

### Timeline of all snapshots
The timeline of various metrics across all snapshots can be viewed on the **Statistics: Timeline** page, allowing you to see how these metrics have developed over time.

To select the metrics type to display, use the top-left drop-down list.

### Managing snapshots
The **Snapshots: Manage** page shows you an overview of all snapshots taken. It's also possible to delete existing snapshots here.

### Taking snapshots
To manually take a new snapshot, browse to the **Snapshots: Take snapshot** page. Optionally enter a comment for your new snapshot, and with a click on the **Take snapshot** button, a new snapshot will be created!

Note that the snapshot will even be taken if you browse away from this page while the process is still running.

### Settings
Snapshots can be configured using the **Settings: Snapshot** page. The following settings are available:

#### General
| Name                            | Description                                                                                                                                                                                                                                                             | Default value |
|---------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------|
| **Automatic snapshot interval** | This settings specifies how frequently automatic snapshots will be taken. Leaving this setting empty will disable automatic snapshots. _Note that Cron jobs must be enabled in the ownCloud settings for this feature to work._                                         | `1d`          |
| **Maximum snapshot age**        | To limit the number of snapshots, Sccuot NG can automatically delete snapshots that have surpassed a certain age. Leaving this setting empty will disable automatic snapshots. _Note that Cron jobs must be enabled in the ownCloud settings for this feature to work._ | `30d`         |

#### File types groups
This list allows you to configure the various file types groups that are displayed in the **File types** statistics page. Each group consists of a name as well as one or more file type endings that shall belong to this group.

If you wish to temporarily stop a group from being counted, you can uncheck the corresponding `Collect` check box.

The option `Filter out files belonging to closed accounts` will ignore any files that belong to closed user accounts. Enabling this option can, however, significantly impact the overall performance of taking snapshots.

#### Advanced
| Name                 | Description | Default value |
|----------------------|-------------|---------------|
| **Query chunk size** | Gathering snapshot values can be performed in chunks. This can improve the overall stability of this process, but will also impact its performance.           | `100000`      |

### Command-line commands
Sccuot NG can also be controlled through the `occ` command. The following commands are currently supported:

| Command            | Description                    |
|--------------------|--------------------------------|
| `sccuot_ng:take`   | Takes a new snapshot.          |
| `sccuot_ng:list`   | Lists all available snapshots. |
| `sccuot_ng:delete` | Deletes one or more snapshots. |

To get more information about each command, including supported parameters, use `occ help <command>`.

### Prometheus metrics
The latest snapshot is exposed as Prometheus metrics at the `/metrics` endpoint. An example URL looks like this:
```
https://www.my-owncloud.org/index.php/apps/sccuot_ng/metrics
```
This endpoint can be scraped by Prometheus to further process all metrics collected in a snapshot.

## Important notes on taking snapshots
Creating a snapshot can take, depending of the size of your ownCloud instance, a substantial amount of time. We therefore recommend to not take snapshots too often on large instances, and only take them during quiet hours.

Also note that since Sccuot NG gathers its information from the ownCloud database and does not access the stored files directly, the gathered results might not be perfectly accurate in all cases.

## Questions? Feedback?
Got any questions or feedback? We are always happy to hear from you! For any inquiries regarding Sccuot NG, you can write an email to [oc.wwuit@uni-muenster.de](mailto:oc.wwuit@uni-muenster.de).
