<?php

namespace OCA\sccuot_ng\Migrations;

use Doctrine\DBAL\Schema\Schema;

use OCA\SccuotNG\Db\{
    Snapshot,
    SnapshotMapper
};

use OCP\Migration\ISchemaMigration;

/* First migration step: Create all basic Sccuot tables */
class Version20211130123513 implements ISchemaMigration {
    private string $prefix;

	public function changeSchema(Schema $schema, array $options) {
        $this->prefix = $options['tablePrefix'];

        $this->createSnapshotsTable($schema);
    }

    private function createSnapshotsTable(Schema $schema) {
        $table = $this->dropAndCreateTable("{$this->prefix}" . SnapshotMapper::SNAPSHOTS_TABLE, $schema);

        // General columns
        $table->addColumn(Snapshot::ID_FIELD, 'integer', [
            'autoincrement' => true,
            'unsigned' => true,
            'notnull' => true,
        ]);
        $table->addColumn(Snapshot::TIMESTAMP_FIELD, 'bigint', [
            'notnull' => true,
            'default' => 0,
        ]);
        $table->addColumn(Snapshot::USERNAME_FIELD, 'string', [
            'notnull' => true,
            'length' => 64,
            'default' => '',
        ]);
        $table->addColumn(Snapshot::COMMENT_FIELD, 'string', [
            'notnull' => true,
            'length' => 255,
            'default' => '',
        ]);
        $table->setPrimaryKey(['id']);

        // Value columns
        $valueColumns = [
            Snapshot::USERS_COUNT_FIELD,
            Snapshot::FILES_COUNT_FIELD,
            Snapshot::FILES_SIZE_FIELD,
            Snapshot::SHARES_COUNT_FIELD,
            Snapshot::FILE_TYPES_COUNTS_FIELD,
        ];
        foreach ($valueColumns as $col) {
            $table->addColumn($col, 'text', [
                'notnull' => false,
            ]);
        }
    }

    private function dropAndCreateTable($tableName, Schema $schema) {
        if ($schema->hasTable($tableName)) {
            $schema->dropTable($tableName);
        }
        return $schema->createTable($tableName);
    }
}
