'use strict';

class TimelineValueDescriptor {
    static TYPE_INTEGER = 0;
    static TYPE_FILESIZE = 1;

    constructor(path, name, type) {
        this._path = path;
        this._name = name;
        this._type = type;
    }

    getPath() {
        return this._path;
    }

    getName() {
        return this._name;
    }

    getType() {
        return this._type;
    }
}

class TimelineValues {
    constructor() {
        this._createValues();
    }

    _createValues() {
        this._values = {};

        let self = this;
        let addValue = function (path, name, type = TimelineValueDescriptor.TYPE_INTEGER) {
            self._values[path] = new TimelineValueDescriptor(path, name, type);
        };

        addValue("files_count.total", "Total files count");
        addValue("files_size.total", "Total files size", TimelineValueDescriptor.TYPE_FILESIZE);
        addValue("users_count.total", "Total users count");
        addValue("groups_count", "Groups count");
        addValue("shares_count.total", "Shares count");
    }

    values() {
        return this._values;
    }

    value(key) {
        return this._values[key];
    }

    valueKeys() {
        return Object.entries(this._values);
    }

    contains(key) {
        return key in this._values;
    }

    fromSnapshot(snapshot, key) {
        if (!this.contains(key)) {
            return 0;
        }

        try {
            let obj = snapshot.values;
            return key.split('.').reduce((o, i) => o[i], obj);
        } catch (e) {
            return 0;
        }
    }

    toJSON() {
        let data = {};
        for (const key in this._values) {
            data[key] = this._values[key].getName();
        }
        return data;
    }
}
