'use strict';

class FileTypesGroupsListItems {
    constructor(fileTypesGroups, elementChildIdPrefix) {
        this._elementChildIdPrefix = elementChildIdPrefix;

        this.assign(fileTypesGroups);
    }

    assign(fileTypesGroups) {
        this._fileTypesGroups = {};
        if (fileTypesGroups !== null) {
            let index = 0;
            for (let groupName in fileTypesGroups) {
                this._fileTypesGroups[groupName] = this._createItem(groupName, fileTypesGroups[groupName], this._createAdditionalProperties(index++));
            }
        }
    }

    newItem(groupName) {
        return (this._fileTypesGroups[groupName] = this._createItem(
            groupName,
            {file_types: [], collect: true},
            this._createAdditionalProperties(Object.keys(this._fileTypesGroups).length, true)
        ));
    }

    updateItem(group, newGroupName, newFileTypes) {
        delete this._fileTypesGroups[group.name];
        this._fileTypesGroups[newGroupName] = this._createItem(newGroupName, group.group, group.properties);
        group.name = newGroupName;
        group.group.file_types = newFileTypes;
        group.properties.is_new = false;
    }

    deleteItem(group) {
        if (this._fileTypesGroups.hasOwnProperty(group.name)) {
            delete this._fileTypesGroups[group.name];
        }
    }

    getItems(ordered = false) {
        let groups = this._fileTypesGroups;
        if (ordered) {
            // Order groups ascending by their group names, leaving new items at the bottom
            let orderedGroups = [];
            for (let groupName in this._fileTypesGroups) {
                orderedGroups.push(this._fileTypesGroups[groupName]);
            }
            orderedGroups.sort((a, b) => { let factor = 1; if (a.properties.is_new || b.properties.is_new) factor = -1; return a.name.localeCompare(b.name) * factor; })
            groups = {};
            for (let i = 0; i < orderedGroups.length; ++i) {
                groups[orderedGroups[i].name] = orderedGroups[i];
            }
        }
        return groups;
    }

    getFileTypesGroups(ordered = false) {
        let groups = this.getItems(ordered);
        for (let groupName in groups) {
            let group = this._fileTypesGroups[groupName];
            groups[group.name] = group.group;
        }
        return groups;
    }

    removePendingNewItems() {
        let pendingNewItems = [];
        for (let groupName in this._fileTypesGroups) {
            if (this._fileTypesGroups[groupName].properties.is_new) {
                pendingNewItems.push(groupName);
            }
        }
        for (let groupName of pendingNewItems) {
            delete this._fileTypesGroups[groupName];
        }
    }

    disableEditingForAll() {
        for (let groupName in this._fileTypesGroups) {
            this._fileTypesGroups[groupName].properties.is_editing = false;
        }
    }

    findGroupByIndex(groupIndex) {
        for (let groupName in this._fileTypesGroups) {
            let group = this._fileTypesGroups[groupName];
            if (group.properties.index === groupIndex) {
                return group;
            }
        }
        return null;
    }

    findGroupByName(group) {
        for (let groupName in this._fileTypesGroups) {
            if (groupName.localeCompare(group, undefined, {sensitivity: 'base'}) === 0) {
                return this._fileTypesGroups[groupName];
            }
        }
        return null;
    }

    _createItem(groupName, group, properties = {}) {
        return {
            name: groupName,
            group: group,
            properties: properties
        }
    }

    _createAdditionalProperties(index, isNewGroup = false) {
        let properties = {};

        // Unique index
        properties.index = this._getChildElementName(String(index));

        // Status
        properties.is_new = isNewGroup;
        properties.is_editing = false;

        // Element IDs
        properties.groupname_id = this._getChildElementName(__elementChildGroupName);
        properties.filetypes_id = this._getChildElementName(__elementChildFileTypes);
        properties.collect_id = this._getChildElementName(__elementChildCollect);
        properties.edit_id = this._getChildElementName(__elementChildEdit);
        properties.edit_apply_id = this._getChildElementName(__elementChildEditApply);
        properties.edit_cancel_id = this._getChildElementName(__elementChildEditCancel);
        properties.delete_id = this._getChildElementName(__elementChildDelete);

        return properties;
    }

    _getChildElementName(childName) {
        return this._elementChildIdPrefix + childName;
    }
}
