'use strict';

class ListControl {
    constructor(elementId, cookieName = '') {
        this._elementId = elementId;
        this._cookieName = cookieName;

        this._changeCallback = null;
    }

    populate() {
        this._bindActions();
        this._populate();

        let activeValue = null;
        if (this._cookieName !== '') {
            let storedValue = this._loadCookie();
            if (storedValue !== null) {
                activeValue = storedValue;
            }
        }
        this._activateValue(activeValue);
    }

    element() {
        return $(this._elementId);
    }

    currentValue() {
        return this.element().val();
    }

    setCurrentValue(value) {
        this._activateValue(value);
    }

    currentIndex() {
        return parseInt(this.element().prop('selectedIndex'));
    }

    change(callback = undefined) {
        if (callback !== undefined) {
            this._changeCallback = callback;
        } else if (this._changeCallback !== null) {
            this._changeCallback(this.currentValue());
        }
    }

    _populate() {
    }

    _bindActions() {
        let self = this;
        this.element().change(function () {
            let selected = self.currentValue();
            self._activateValue(selected);
        });
    }

    _activateValue(value) {
        let currentValue = this.currentValue();
        if (value !== currentValue) {
            let valueSelected = false;
            if (value !== null) {
                this.element().val(value);
                valueSelected = true;
            }
            if (!valueSelected) {
                this.element().prop('selectedIndex', 0);
            }
        }

        this.change();

        if (this._cookieName !== '') {
            this._saveCookie();
        }
    }

    _saveCookie() {
        let currentValue = this.currentValue();
        Cookies.set(this._cookieName, currentValue, {sameSite: 'strict', expires: 365});
    }

    _loadCookie() {
        let value = Cookies.get(this._cookieName);
        if (value === undefined) {
            value = null;
        }
        return value;
    }
}
