'use strict';

class SnapshotsList {
    constructor(elementId, templates, cookieName = '') {
        this._elementId = elementId;
        this._templates = templates;

        this._snapshots = null;
        this._activeSnapshot = null;
        this._changeCallback = null;

        this._cookieName = cookieName;
    }

    preparePopulate() {
        this._snapshots = null;
        this._activeSnapshot = null;
        this._renderSnapshotsList(this._templates.loading, false);
    }

    populate(snapshots, activeSnapshot = false) {
        this._snapshots = snapshots;
        if (this._snapshots.length !== 0) {
            if (this._cookieName !== '') {
                let storedSnapshot = this._getStoredSnapshot(snapshots);
                if (storedSnapshot !== null) {
                    activeSnapshot = storedSnapshot;
                }
            }

            if (activeSnapshot !== false) {
                this.activateSnapshot(activeSnapshot);
            }
            this._snapshots.forEach((snapshot) => { snapshot.is_active = this.isSnapshotActive(snapshot); });

            this._renderSnapshotsList(this._templates.list, true, {snapshots: this._snapshots});
        } else {
            this._renderSnapshotsList(this._templates.empty, false);
        }
    }

    populateError() {
        this._renderSnapshotsList(this._templates.error, false);
    }

    _renderSnapshotsList(content, enabled, data = {}) {
        this._element().prop('disabled', !enabled);

        renderHandlebarsTemplate(content, this._elementId, data);
    }

    _element() {
        return $(this._elementId);
    }

    activateSnapshot(snapshot) {
        if (this._activeSnapshot === snapshot) {
            return;
        }

        this._activeSnapshot = snapshot;
        this.change();

        if (this._cookieName !== '') {
            this._saveCookie();
        }
    }

    activeSnapshot() {
        let activeSnapshot = this._activeSnapshot;
        if (typeof activeSnapshot === "number" && this._snapshots !== null) {
            activeSnapshot = findSnapshot(parseInt(activeSnapshot), this._snapshots);
        }
        return activeSnapshot;
    }

    isSnapshotActive(snapshot) {
        return compareSnapshots(snapshot, this._activeSnapshot);
    }

    change(callback = undefined) {
        if (callback !== undefined) {
            this._changeCallback = callback;
        } else if (this._changeCallback !== null) {
            this._changeCallback(this._activeSnapshot);
        }
    }

    _getStoredSnapshot(snapshots) {
        if (snapshots.length !== 0) {
            let storedId = this._loadCookie();
            if (storedId !== null) {
                for (let snapshot of snapshots) {
                    if (snapshot.id === storedId) {
                        return snapshot.id;
                    }
                }
            }
        }
        return null;
    }

    _saveCookie() {
        if (this._activeSnapshot !== null) {
            Cookies.set(this._cookieName, typeof this._activeSnapshot === "object" ? this._activeSnapshot.id : this._activeSnapshot, {sameSite: 'strict', expires: 365}
            );
        } else {
            Cookies.remove(this._cookieName);
        }
    }

    _loadCookie() {
        let value = Cookies.get(this._cookieName);
        if (value === undefined) {
            value = null;
        }
        return parseInt(value);
    }
}
