'use strict';

class SubPageContainer {
    constructor(renderTarget, tabBar = null) {
        this._pages = [];
        this._currentPage = null;

        this._renderTarget = renderTarget;
        this._tabBar = tabBar;

        this._changeCallback = null;

        this._bindTabBarChange();
    }

    addPage(page) {
        this._tabBar?.addTab(page.title());

        let length = this._pages.push(page);
        if (this._currentPage === null) {
            this._currentPage = length - 1;
        }
        return length - 1;
    }

    render() {
        this._preRenderContent();

        this._tabBar?.render();

        let activePage = this._activePage();
        if (activePage !== null) {
            activePage.render(this._renderTarget, this._getContentData());
        } else {
            $(this._renderTarget).html('');
        }

        this._postRenderContent();
    }

    _getContentData() {
        return {};
    }

    _preRenderContent() {
    }

    _postRenderContent() {
    }

    setCurrentPage(index) {
        let activePage = this._activePage();
        activePage?.onDeactivate();

        if (index < 0 || index >= this._pages.length) {
            index = null;
        }

        if (index === this._currentPage) {
            return;
        }
        this._currentPage = index;
        this.change();

        this._tabBar?.setCurrentTab(index);

        activePage = this._activePage();
        activePage?.onActivate();

        this.render();
    }

    pages() {
        return this._pages;
    }

    currentPage() {
        return this._currentPage;
    }

    change(callback = undefined) {
        if (callback !== undefined) {
            this._changeCallback = callback;
        } else if (this._changeCallback !== null) {
            this._changeCallback(this._currentPage);
        }
    }

    populateTabBar(tabBar) {
        for (let page of this._pages) {
            tabBar.addTab(page.title());
        }
    }

    _bindTabBarChange() {
        let self = this;
        this._tabBar?.change(function (index) {
            self.setCurrentPage(index);
        });
    }

    _activePage() {
        if (this._currentPage === null) {
            return null;
        }
        return this._pages[this._currentPage];
    }
}
