'use strict';

class TabBar {
    constructor(tabPrefix, renderTarget, templateId = '#tab-bar-tpl') {
        this._tabs = [];
        this._currentTab = null;
        this._tabPrefix = tabPrefix;

        this._templateId = templateId;
        this._renderTarget = renderTarget;

        this._changeCallback = null;

        let self = this;
        $(window).resize(function () {
            self._updateTabBehavior();
        });
    }

    addTab(title) {
        let tab = {
            index: this._tabs.length,
            section: this._getSectionId(this._tabs.length),
            id: this._getTabId(this._tabs.length),
            title: title
        }
        let length = this._tabs.push(tab);
        if (this._currentTab === null) {
            this._currentTab = length - 1;
        }
        return length - 1;
    }

    render() {
        this._preRenderContent();

        this._updateTabsActiveState();
        renderHandlebarsTemplate(this._templateId, this._renderTarget, {tabs: this._tabs});

        this._bindTabActions();
        this._updateTabBehavior();
        this._postRenderContent();
    }

    _preRenderContent() {
    }

    _postRenderContent() {
    }

    _updateTabsActiveState() {
        this._tabs.forEach((tab) => { tab.is_active = (tab.index === this._currentTab); });
    }

    _bindTabActions() {
        let self = this;
        for (let tab of this._tabs) {
            if (!tab.is_active) {
                $('#' + tab.id).click(function (event) {
                    event.preventDefault();

                    self.setCurrentTab(tab.index);
                });
            }
        }
    }

    setCurrentTab(index) {
        if (index < 0 || index >= this._tabs.length) {
            index = null;
        }

        if (index === this._currentTab) {
            return;
        }
        this._currentTab = index;
        this.change();

        this.render();
    }

    prevTab(wrapAround = true) {
        this._jumpTab(-1, wrapAround);
    }

    nextTab(wrapAround = true) {
        this._jumpTab(+1, wrapAround);
    }

    _jumpTab(direction, wrapAround) {
        if (this._currentTab === null) {
            return;
        }

        let index = this._currentTab + direction;
        if (index < 0) {
            index = wrapAround ? this._tabs.length - 1 : 0;
        } else if (index >= this._tabs.length) {
            index = wrapAround ? 0 : this._tabs.length - 1;
        }
        this.setCurrentTab(index);
    }

    _updateTabBehavior() {
        const tabMinWidth = 25;

        let self = this;
        for (let tab of this._tabs) {
            // Set word breaking behavior: By default, use per-word; if the element is too small, use per-letter
            let sectionElem = $('#' + tab.section);
            let sepWidth = 0;
            sectionElem.children('.tab-bar-separator').each(function () {
                sepWidth += $(this).outerWidth(true);
            });

            sectionElem.css('word-break', sectionElem.text().split(' ').length === 1 || sectionElem.width()-sepWidth < tabMinWidth*2 ? 'break-all' : 'break-word');
            sectionElem.css('min-width', tabMinWidth+sepWidth);
        }
    }

    tabs() {
        return this._tabs;
    }

    currentTab() {
        return this._currentTab;
    }

    change(callback = undefined) {
        if (callback !== undefined) {
            this._changeCallback = callback;
        } else if (this._changeCallback !== null) {
            this._changeCallback(this._currentTab);
        }
    }

    _getTabId(index) {
        return this._tabPrefix + '-' + String(index);
    }

    _getSectionId(index) {
        return this._tabPrefix + '-section-' + String(index);
    }
}
