'use strict';

(function (OC, window, $) {
    class ManageSnapshotsView extends View {
        constructor(handler) {
            super(handler);

            this._snapshotsList = new SnapshotsList('#snapshots-table', {list: '#snapshots-table-tpl', loading: '#snapshots-loading-tpl', empty: '#snapshots-empty-tpl', error: '#snapshots-error-tpl'});
        }

        _postRenderContent() {
            super._postRenderContent();

            this._updateSnapshotsList();
        };

        _updateSnapshotsList() {
            this._snapshotsList.preparePopulate();
            this._updateSnapshotsListState();

            let self = this;
            this.handler().refreshSnapshots().done(function (snapshots) {
                self._snapshotsList.populate(snapshots);
                self._updateSnapshotsListState();
            }).fail(function () {
                self._snapshotsList.populateError();
                self._updateSnapshotsListState();
            });
        }

        _updateSnapshotsListState() {
            this._bindSnapshotsListActions();
            this._updateSnapshotListsButtonStates();
        }

        _updateSnapshotListsButtonStates() {
            $('#snapshots-delete').prop('disabled', !$('#snapshots-table * input[type=checkbox]').is(':checked'));
        }

        _bindSnapshotsListActions() {
            let self = this;

            $("#select-all").click(function () {
                $('#snapshots-table * input[type=checkbox]').each(function () {
                    this.checked = true;
                });
                self._updateSnapshotListsButtonStates();
            });
            $("#select-none").click(function () {
                $('#snapshots-table * input[type=checkbox]').each(function () {
                    this.checked = false;
                });
                self._updateSnapshotListsButtonStates();
            });
            $("#select-invert").click(function () {
                $('#snapshots-table * input[type=checkbox]').each(function () {
                    this.checked = !this.checked;
                });
                self._updateSnapshotListsButtonStates();
            });

            $('#snapshots-table * input[type=checkbox]').change(function () {
                self._updateSnapshotListsButtonStates();
            });

            $('#snapshots-delete').click(function () {
                let snapshotIDs = [];
                $('#snapshots-table * input[type=checkbox]:checked').each(function () {
                    snapshotIDs.push(parseInt(this.value));
                });
                self._deleteSnapshots(snapshotIDs.reverse());
            });
        }

        _deleteSnapshots(snapshotIDs) {
            if (!snapshotIDs) {
                return;
            }

            this.infoMessage('Deleting snapshots', 'Deleting snapshots ' + snapshotIDs.join(', ') + "... The table contents will be refreshed after completing the operation.");

            $('#snapshots-table * input[type=checkbox]').prop('disabled', true);
            $('#snapshots-delete').prop('disabled', true);

            let self = this;
            this.handler().deleteSnapshots(snapshotIDs).done(function (resp) {
                let count = resp.data().count;
                if (count > 1) {
                    self.successMessage('Snapshots deleted', String(count) + ' snapshots have been successfully deleted.');
                } else {
                    self.successMessage('Snapshots deleted', 'One snapshot has been successfully deleted.');
                }
                self._updateSnapshotsList();
            }).fail(function (reason) {
                self.errorMessage('Snapshots not deleted', reason.formatError('The snapshots could not be deleted'));
                self._updateSnapshotsList();
            });
        }
    }

    $(document).ready(function () {
        let handler = new SnapshotsHandler(OC.generateUrl('/apps/sccuot_ng/snapshot'));

        let view = new ManageSnapshotsView(handler);
        view.render();
    });
})(OC, window, jQuery);
