'use strict';

class UsersStoragePage extends HistogramPage {
    constructor() {
        super('Users storage', '#stats-users-storage-tpl', '#users-storage-chart', '#histogram-users-storage-bin-count');

        this._refreshTimer = -1;
    }

    _getHistogramData(data) {
        return {
            data: Array.isArray(data.active_snapshot.values.users_storage) ? data.active_snapshot.values.users_storage : null,
            isFloats: false,
        }
    }

    _postRenderContent() {
        super._postRenderContent();

        $('#histogram-users-storage-limits-unit').html(this._fileSizeUnit);

        this._bindFileSizeLimitActions("#histogram-users-storage-min-limit");
        this._bindFileSizeLimitActions("#histogram-users-storage-max-limit");
    }

    _bindFileSizeLimitActions(id) {
        let self = this;
        $(id).on("input", function () {
            // Start a refresh timer
            if (self._refreshTimer !== -1) {
                clearTimeout(self._refreshTimer);
            }

            self._refreshTimer = setTimeout(() => {
                self._refreshTimer = -1;
                self._createHistogramChart();
            }, 500);
        });
    }

    _getAdditionalOptions(options) {
        options.scales.y.ticks = {
            stepSize: 1,
        };
    }

    _getMinimumDeltaValue() {
        return 1;
    }

    _getHistogramLimits() {
        let minLimit = Math.max(parseInt($('#histogram-users-storage-min-limit').val()), 0);
        let maxLimit = Math.max(parseInt($('#histogram-users-storage-max-limit').val()), 0);
        return {
            minLimit: minLimit * this._fileSizeUnitFactor,
            maxLimit: maxLimit * this._fileSizeUnitFactor
        };
    }

    _formatValue(value) {
        return formatFileSize(value, this._fileSizeUnitFactor, this._fileSizeUnit);
    }
}

StatisticsPages.registerPageClass(UsersStoragePage);
