'use strict';

(function (OC, window, $) {
    class StatisticsView extends View {
        constructor(handler) {
            super(handler);

            this._snapshotsList = new SnapshotsDropDown('#snapshots-list', 'SccuotNG_stats-active-snapshot');
            this._fileSizeUnits = new FileSizeUnitsDropDown('#filesize-units', 'SccuotNG_stats-active-unit');
            this._contentPages = null;
        }

        _postRenderContent() {
            super._postRenderContent();

            this._showNoSnapshotsBox(false);

            this._updateSnapshotsList();
            this._fileSizeUnits.populate();
        }

        _updateSnapshotsList() {
            this._snapshotsList.preparePopulate();
            this._prepareContentPages();

            let self = this;
            this.handler().refreshSnapshots().done(function (snapshots) {
                self._snapshotsList.populate(snapshots);
                self._bindSnapshotsListChange();
                self._bindFileSizeUnitsChange();
                self._createContentPages();
                self._showNoSnapshotsBox(snapshots.length === 0);
            }).fail(function () {
                self._snapshotsList.populateError();
            });
        }

        _prepareContentPages() {
            this._contentPages = new StatisticsPages();
            this._updatePageContent();
        }

        _createContentPages() {
            this._contentPages.createPages();
            this._updatePageContent();
        }

        _updatePageContent() {
            this._contentPages.setSnapshots(this.handler().snapshots());
            this._contentPages.setActiveSnapshot(this._snapshotsList.activeSnapshot());
            this._contentPages.setFileSizeUnit(this._fileSizeUnits.activeUnit());
            this._contentPages.render();
        }

        _bindSnapshotsListChange() {
            let self = this;
            this._snapshotsList.change(function (snapshot) {
                self._updatePageContent();
            });
        }

        _bindFileSizeUnitsChange() {
            let self = this;
            this._fileSizeUnits.change(function (value) {
                self._updatePageContent();
            });
        }

        _showNoSnapshotsBox(show = true) {
            if (show) {
                $("#stats-container-empty").show();
            } else {
                $("#stats-container-empty").hide();
            }
        }
    }

    $(document).ready(function () {
        let handler = new SnapshotsHandler(OC.generateUrl('/apps/sccuot_ng/snapshot'));

        let view = new StatisticsView(handler);
        view.render();
    });
})(OC, window, jQuery);
