<?php

namespace OCA\SccuotNG\Command;

use OCA\SccuotNG\Util\OutputProxy;

use Exception;
use Symfony\Component\Console\Input\{
    InputInterface,
    InputOption
};

class TakeSnapshotCommand extends SccuotCommand {
	const PARAM_CHUNKSIZE = 'chunksize';
    const PARAM_COMMENT = 'comment';

    protected function configure() {
        $this->setName('sccuot_ng:take')
            ->setDescription('Takes a new snapshot.')
	        ->addOption(self::PARAM_CHUNKSIZE, 's', InputOption::VALUE_REQUIRED, 'The query chunk size', '')
            ->addOption(self::PARAM_COMMENT, 'c', InputOption::VALUE_REQUIRED, 'An optional snapshot comment', '');
    }

    protected function executeCommand(InputInterface $input) {
        try {
            OutputProxy::println('Taking snapshot... ');

			$chunkSize = $this->getChunkSize($input);
            $comment = $input->getOption(self::PARAM_COMMENT);
            $snapshot = $this->snapshotService->take($chunkSize, $comment);

	        OutputProxy::println("Snapshot has been successfully taken (id={$snapshot->getId()}).");
        } catch (Exception $e) {
	        OutputProxy::println("Unable to take snapshot: {$e->getMessage()}");
        }
    }

	private function getChunkSize(InputInterface $input) {
		$chunkSize = $input->getOption(self::PARAM_CHUNKSIZE);
		if ($chunkSize === "") {
			$chunkSize = $this->configService->getQueryChunksize();
		}
		return $chunkSize;
	}
}
