<?php

namespace OCA\SccuotNG\Controller;

use Exception;

use OCA\SccuotNG\Http\HandlerResponse;
use OCA\SccuotNG\Service\ConfigService;

use OCP\IRequest;
use OCP\AppFramework\{
    Controller,
    Http,
    Http\TemplateResponse
};

class ConfigController extends Controller {
    private ConfigService $configService;

    public function __construct($AppName, IRequest $request, ConfigService $configService) {
        parent::__construct($AppName, $request);

        $this->configService = $configService;
    }

    /*** API endpoints ***/

    /**
     * @NoCSRFRequired
     */
    public function get() {
        return new HandlerResponse('Current configuration', $this->configService->jsonSerialize());
    }

    /**
     * @NoCSRFRequired
     */
    public function getDefaults() {
        return new HandlerResponse('Configuration defaults', $this->configService->defaults());
    }

    public function set(string $settings) {
        try {
            $data = json_decode($settings, true);
            $this->configService->jsonDeserialize($data);
            return new HandlerResponse('Configuration saved', $this->configService->jsonSerialize());
        } catch (Exception $e) {
            return new HandlerResponse('Unable to save configuration: ' . $e->getMessage(), [], Http::STATUS_INTERNAL_SERVER_ERROR);
        }
    }

    /*** Page endpoints ***/

    /**
     * @NoCSRFRequired
     */
    public function snapshotSettingsPage() {
        $data = [
            'config' => $this->configService->jsonSerialize(),
            'defaults' => $this->configService->defaults(),
        ];
        return new TemplateResponse($this->appName, 'config/snapshotSettings', $data);
    }
}
