<?php

namespace OCA\SccuotNG\Controller;

use OCA\SccuotNG\Http\HandlerResponse;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\SnapshotService;

use Exception;

use OCP\IRequest;
use OCP\AppFramework\{
    Controller,
    Http,
    Http\TemplateResponse
};

class SnapshotController extends Controller {
    private SnapshotService $snapshotService;
	private ConfigService $configService;

    public function __construct($AppName, IRequest $request, SnapshotService $snapshotService, ConfigService $configService) {
        parent::__construct($AppName, $request);

        $this->snapshotService = $snapshotService;
		$this->configService = $configService;
    }

    /*** API endpoints ***/

	/**
	 * @NoAdminRequired
	 * @NoCSRFRequired
	 */
    public function get(int $id) {
        try {
            $snapshot = $this->snapshotService->find($id);
            return new HandlerResponse('Snapshot ' . $snapshot->getId(), $snapshot);
        } catch (Exception $e) {
            return new HandlerResponse('Unable to get snapshot ' . $id . ': ' . $e->getMessage(), [], Http::STATUS_NOT_FOUND);
        }
    }

	/**
	 * @NoAdminRequired
	 * @NoCSRFRequired
	 */
    public function getAll() {
        $snapshots = $this->snapshotService->getAll();
        return new HandlerResponse('All snapshots', $snapshots);
    }

    public function take(string $comment = "") {
        try {
			$chunkSize = $this->configService->getQueryChunksize();
            $snapshot = $this->snapshotService->take($chunkSize, $comment);
            return new HandlerResponse('Snapshot taken', $snapshot);
        } catch (Exception $e) {
            return new HandlerResponse('Unable to take snapshot: ' . $e->getMessage(), [], Http::STATUS_INTERNAL_SERVER_ERROR);
        }
    }

    public function delete(string $ids) {
        try {
            $idList = array_map('intval', explode(',', $ids));
            $count = $this->snapshotService->deleteMultiple($idList);
            return new HandlerResponse("{$count} snapshot(s) deleted (ids={$ids})", ["count" => $count]);
        } catch (Exception $e) {
            return new HandlerResponse('Unable to delete snapshots ' . $ids . ': ' . $e->getMessage(), [], Http::STATUS_NOT_FOUND);
        }
    }

    /*** Page endpoints ***/

    /**
     * @NoCSRFRequired
     */
    public function takePage() {
        return new TemplateResponse($this->appName, 'snapshot/take');
    }

    /**
     * @NoCSRFRequired
     */
    public function managePage() {
        return new TemplateResponse($this->appName, 'snapshot/manage');
    }
}
