<?php

namespace OCA\SccuotNG\Data;

use JsonSerializable;

class FileTypesGroup implements JsonSerializable {
    private array $fileTypes = [];
    private bool $collect = true;

    public function add($ft) {
        if (!$this->contains($ft)) {
            $this->fileTypes[] = $this->normalize($ft);
        }
    }

    public function remove($ft) {
        if ($this->contains($ft)) {
            unset($this->fileTypes[$this->normalize($ft)]);
        }
    }

    public function contains($ft) {
        $ft = $this->normalize($ft);
        return array_key_exists($this->normalize($ft), $this->fileTypes);
    }

    public function getFileTypes() {
        return $this->fileTypes;
    }

    public function setFileTypes(array $fileTypes) {
        $this->fileTypes = $fileTypes;
        $this->normalizeAll();
    }

    public function isCollectEnabled() {
        return $this->collect;
    }

    public function setCollectEnabled(bool $enable = true) {
        $this->collect = $enable;
    }

    public function parse(string $fileTypes) {
        $this->fileTypes = preg_split('/[;,\s]/', $fileTypes);
        $this->normalizeAll();
    }

    public function jsonSerialize() {
        return [
            'file_types' => $this->fileTypes,
            'collect' => $this->collect,
        ];
    }

    public function jsonDeserialize($data) {
        if (array_key_exists('file_types', $data)) {
            $this->fileTypes = $data['file_types'];
            $this->normalizeAll();
        }

        if (array_key_exists('collect', $data)) {
            $this->collect = $data['collect'];
        }
    }

    private function normalize($ft) {
        $ftNormalized = trim(strtolower($ft));
        if (substr($ftNormalized, 0, 1) !== ".") {
            $ftNormalized = "." . $ftNormalized;
        }
        return $ftNormalized;
    }

    private function normalizeAll() {
        for ($i = 0; $i < count($this->fileTypes); ++$i) {
            $this->fileTypes[$i] = $this->normalize($this->fileTypes[$i]);
        }
    }
}

class FileTypesGroups implements JsonSerializable {
    private array $groups = [];

    public function group($name) {
        if (!$this->contains($name)) {
            $this->groups[$name] = new FileTypesGroup();
        }
        return $this->groups[$name];
    }

    public function contains($name) {
        return array_key_exists($name, $this->groups);
    }

    public function remove($name) {
        if ($this->contains($name)) {
            unset($this->groups[$name]);
        }
    }

    public function groups() {
        return $this->groups;
    }

    public function jsonSerialize() {
        return $this->groups;
    }

    public function jsonDeserialize($data) {
        if (!is_array($data)) {
            return;
        }

        $this->groups = [];
        foreach ($data as $name => $fileTypes) {
            $ftg = new FileTypesGroup();
            $ftg->jsonDeserialize($fileTypes);
            $this->groups[$name] = $ftg;
        }
    }
}
