<?php

namespace OCA\SccuotNG\Db\OC;

use OCA\SccuotNG\Db\ExtMapper;

use OCP\DB\QueryBuilder\IQueryBuilder;
use OCP\IDBConnection;

use OC\Share\Constants;

class SharesMapper extends ExtMapper {
    const SHARES_TABLE = 'share';

    public function __construct(IDBConnection $db, int $chunkSize) {
        parent::__construct($db, self::SHARES_TABLE, $chunkSize);
    }

	public function queryTotalCount() {
		$data = [
			'count' => 0
		];
		$this->chunkedQuery('id', array($this, 'queryTotalCountCallback'), $data);
		return $data['count'];
	}

    protected function queryTotalCountCallback(IQueryBuilder $query, $offset, &$data): int {
        $query->selectAlias($query->createFunction('COUNT(*)'), 'c')
	        ->selectAlias($query->createFunction('MAX(id)'), 'm')
            ->from(self::SHARES_TABLE);
	    $this->addChunkCondition($query,'id', $offset, true);

	    // Query values and add up count
	    $values = $this->queryValues($query, ['c', 'm']);
	    $data['count'] += $values['c'];

	    return $values['m'];
    }

	public function queryFilesCount() {
		$data = [
			'count' => 0
		];
		$this->chunkedQuery('id', array($this, 'queryFilesCountCallback'), $data);
		return $data['count'];
	}

    protected function queryFilesCountCallback(IQueryBuilder $query, $offset, &$data): int {
        $query->selectAlias($query->createFunction('COUNT(*)'), 'c')
	        ->selectAlias($query->createFunction('MAX(id)'), 'm')
            ->from(self::SHARES_TABLE)
            ->where($query->expr()->like('item_type', $query->createPositionalParameter('file')));
	    $this->addChunkCondition($query,'id', $offset);

	    // Query values and add up count
	    $values = $this->queryValues($query, ['c', 'm']);
	    $data['count'] += $values['c'];

	    return $values['m'];
    }

	public function queryFoldersCount() {
		$data = [
			'count' => 0
		];
		$this->chunkedQuery('id', array($this, 'queryFoldersCountCallback'), $data);
		return $data['count'];
	}

    protected function queryFoldersCountCallback(IQueryBuilder $query, $offset, &$data): int {
        $query->selectAlias($query->createFunction('COUNT(*)'), 'c')
	        ->selectAlias($query->createFunction('MAX(id)'), 'm')
            ->from(self::SHARES_TABLE)
            ->where($query->expr()->like('item_type', $query->createPositionalParameter('folder')));
	    $this->addChunkCondition($query,'id', $offset);

	    // Query values and add up count
	    $values = $this->queryValues($query, ['c', 'm']);
	    $data['count'] += $values['c'];

	    return $values['m'];
    }

	public function queryPublicLinksCount() {
		$data = [
			'count' => 0
		];
		$this->chunkedQuery('id', array($this, 'queryPublicLinksCountCallback'), $data);
		return $data['count'];
	}

	protected function queryPublicLinksCountCallback(IQueryBuilder $query, $offset, &$data): int {
		$query->selectAlias($query->createFunction('COUNT(*)'), 'c')
			->selectAlias($query->createFunction('MAX(id)'), 'm')
			->from(self::SHARES_TABLE)
			->where($query->expr()->eq('share_type', $query->createPositionalParameter(Constants::SHARE_TYPE_LINK, IQueryBuilder::PARAM_INT)));
		$this->addChunkCondition($query,'id', $offset);

		// Query values and add up count
		$values = $this->queryValues($query, ['c', 'm']);
		$data['count'] += $values['c'];

		return $values['m'];
	}
}
