<?php

namespace OCA\SccuotNG\Db;

use OCP\DB\QueryBuilder\IQueryBuilder;
use OCP\IDBConnection;

class SnapshotMapper extends ExtMapper {
    const SNAPSHOTS_TABLE = 'sccuot_snapshots';

    public function __construct(IDBConnection $db) {
        parent::__construct($db, self::SNAPSHOTS_TABLE);
    }

    public function getAll() {
        $query = $this->getQueryBuilder();
        $query->select('*')
            ->from(self::SNAPSHOTS_TABLE)
            ->orderBy(Snapshot::ID_FIELD, 'DESC');
        return $this->queryEntities($query);
    }

    public function getNewest() {
        $query = $this->getQueryBuilder();
        $query->setMaxResults(1);
        $query->select('*')
            ->from(self::SNAPSHOTS_TABLE)
            ->orderBy(Snapshot::TIMESTAMP_FIELD, 'DESC');
		$query->setMaxResults(1);
        $entities = $this->queryEntities($query);
        if (count($entities) != 1) {
            return null;
        }
        return $entities[0];
    }

    public function find($id) {
        $query = $this->getQueryBuilder();
        $query->select('*')
            ->from(self::SNAPSHOTS_TABLE)
            ->where($query->expr()->eq(Snapshot::ID_FIELD, $query->createPositionalParameter($id, IQueryBuilder::PARAM_INT)));
        return $this->queryEntity($query);
    }

    public function findByTimestamp($timestamp) {
        $query = $this->getQueryBuilder();
        $query->select('*')
            ->from(self::SNAPSHOTS_TABLE)
            ->where($query->expr()->eq(Snapshot::TIMESTAMP_FIELD, $query->createPositionalParameter($timestamp, IQueryBuilder::PARAM_INT)));
        return $this->queryEntity($query);
    }

    public function deleteMultiple($ids) {
        // Remove multiple snapshots in chunks
        $count = 0;
        $chunks = array_chunk($ids, 100);
        foreach ($chunks as $chunk) {
            $query = $this->getQueryBuilder();
            $query->delete(self::SNAPSHOTS_TABLE)
                ->where($query->expr()->in(Snapshot::ID_FIELD, $query->createPositionalParameter($chunk, IQueryBuilder::PARAM_INT_ARRAY)));
            $count += intval($query->execute());
        }
        return $count;
    }

    public function deleteBefore($timestamp) {
        $query = $this->getQueryBuilder();
        $query->delete(self::SNAPSHOTS_TABLE)
            ->where($query->expr()->lt(Snapshot::TIMESTAMP_FIELD, $query->createPositionalParameter($timestamp, IQueryBuilder::PARAM_INT)));
        return intval($query->execute());
    }
}
