<?php

namespace OCA\SccuotNG\Histogram;

class HistogramBins {
	private $minValue = 0;
	private $maxValue = 0;

	private int $binCount = 0;
	private $binSize = 0;

	private bool $floatValues = false;

	public function __construct($minValue, $maxValue, int $binCount, bool $floatValues = false) {
		$this->minValue = $minValue;
		$this->maxValue = $maxValue;

		$this->binCount = $binCount;
		$this->floatValues = $floatValues;

		$this->updateBinCount();
		$this->updateBinSize();
	}

	public function getBins() {
		$bins = [];
		for ($i = 1; $i <= $this->binCount; ++$i) {
			$bins[] = min($this->minValue + ($this->binSize * $i), $this->maxValue);
		}
		return $bins;
	}

	public function getBinCount() {
		return $this->binCount;
	}

	public function getBinSize() {
		return $this->binSize;
	}

	private function updateBinCount() {
		if ($this->floatValues) {
			$this->binCount = max(1, $this->binCount);
		} else {
			$this->binCount = max(1, min($this->maxValue - $this->minValue, $this->binCount));
		}
	}

	private function updateBinSize() {
		$binSize = ($this->maxValue - $this->minValue) / $this->binCount;
		if (!$this->floatValues) {
			$binSize = ceil($binSize);
		}
		if ($binSize == 0) {
			$binSize = $this->maxValue;
		}
		$this->binSize = $binSize;
	}
}
