<?php

namespace OCA\SccuotNG\Jobs;

use OCA\SccuotNG\Service\SnapshotService;
use OCA\SccuotNG\Misc\TimeInterval;
use OCP\AppFramework\App;

use OC\BackgroundJob\TimedJob;

class SnapshotsJob extends TimedJob {
    protected function run($argument) {
        $app = new App('sccuot_ng');
        $configSvc = $app->getContainer()->query('OCA\SccuotNG\Service\ConfigService');
        $snapshotSvc = $app->getContainer()->query('OCA\SccuotNG\Service\SnapshotService');

        if (($maxAge = TimeInterval::parse($configSvc->getSnapshotMaxAge(), true)) > 0) {
            $this->purgeSnapshots($snapshotSvc, $maxAge);
        }

        if (($interval = TimeInterval::parse($configSvc->getSnapshotInterval(), true)) > 0) {
			$chunkSize = $configSvc->getQueryChunksize();
            $this->takeSnapshot($snapshotSvc, $chunkSize, $interval);
        }
    }

    private function purgeSnapshots(SnapshotService $snapshots, int $maxAge) {
        $obsoleteTime = time() - $maxAge;
        $snapshots->deleteBefore($obsoleteTime);
    }

    private function takeSnapshot(SnapshotService $snapshots, int $chunkSize, int $interval) {
        if (($newestSnapshot = $snapshots->getNewest()) !== null) {
            $minAge = time() - $interval;
            if ($newestSnapshot->getTimestamp() > $minAge) {
                return;
            }
        }

        $snapshots->take($chunkSize,'Automatic snapshot');
    }
}
