<?php

namespace OCA\SccuotNG\Misc;

use InvalidArgumentException;

class TimeInterval {
    const INTERVAL_WEEK = 'w';
    const INTERVAL_DAY = 'd';
    const INTERVAL_HOUR = 'h';
    const INTERVAL_MINUTE = 'm';
    const INTERVAL_SECOND = 's';

    public static function parse(string $interval, bool $ignoreParseErrors = false) {
        $interval = trim($interval);
        if ($interval == '') {
            return 0;
        }

        $out = [];
        preg_match_all('/((\d+)\s?([wWdDhHmMsS]))[\s,;]?/', trim($interval), $out);
        if (count($out) != 4) {
            if ($ignoreParseErrors) {
                return 0;
            }
            throw new InvalidArgumentException('Parsing error');
        }

        $quantities = $out[2];
        $qualifiers = $out[3];
        if (count($quantities) != count($qualifiers)) {
            if ($ignoreParseErrors) {
                return 0;
            }
            throw new InvalidArgumentException('Mismatching quantities and qualifiers counts');
        }

        $intervals = self::getIntervals();
        $interval = 0;
        for ($i = 0; $i < count($quantities); ++$i) {
            $quantity = intval($quantities[$i]);
            $qualifier = strtolower($qualifiers[$i]);

            if (array_key_exists($qualifier, $intervals)) {
                $factor = $intervals[$qualifier];
                $interval += $quantity * $factor;
            } else {
                if ($ignoreParseErrors) {
                    return 0;
                }
                throw new InvalidArgumentException('Unsupported time qualifier ' . $qualifier);
            }
        }
        return $interval;
    }

    private static function getIntervals() {
        return [
            self::INTERVAL_WEEK => 7 * 24 * 60 * 60,
            self::INTERVAL_DAY => 24 * 60 * 60,
            self::INTERVAL_HOUR => 60 * 60,
            self::INTERVAL_MINUTE => 60,
            self::INTERVAL_SECOND => 1,
        ];
    }
}
