<?php

namespace OCA\SccuotNG\Misc;

use JsonSerializable;

class TimePeriod implements JsonSerializable {
    private string $name;
    private int $duration;

    public function __construct(string $name, int $duration) {
        $this->name = $name;
        $this->duration = $duration;
    }

    public function before(int $timestamp) {
        return $timestamp - $this->duration;
    }

    public function after(int $timestamp) {
        return $timestamp + $this->duration;
    }

    public function name() {
        return $this->name;
    }

    public function duration() {
        return $this->duration;
    }

    public function jsonSerialize() {
        return [
            'name' => $this->name,
            'duration' => $this->duration,
        ];
    }
}

class TimePeriods {
    const PERIOD_DAY = 'day';
    const PERIOD_WEEK = 'week';
    const PERIOD_MONTH = 'month';
    const PERIOD_QUARTER = 'quarter';
    const PERIOD_YEAR = 'year';

    public static function periods() {
        $secondsPerDay = 24 * 60 * 60;
        return [
            self::PERIOD_DAY => new TimePeriod("Day", $secondsPerDay),
            self::PERIOD_WEEK => new TimePeriod("Week", $secondsPerDay * 7),
            self::PERIOD_MONTH => new TimePeriod("Month", $secondsPerDay * 30),
            self::PERIOD_QUARTER => new TimePeriod("Quarter", $secondsPerDay * 90),
            self::PERIOD_YEAR => new TimePeriod("Year", $secondsPerDay * 365),
        ];
    }
}
