<?php

namespace OCA\SccuotNG\Service;

require_once __DIR__ . '/../3rdParty/Prometheus/autoload.php';

use OCA\SccuotNG\Histogram\HistogramBins;

use Prometheus\CollectorRegistry;
use Prometheus\Storage\InMemory;

class MetricsService {
	private InMemory $adapter;
	private CollectorRegistry $registry;

	public function __construct() {
		$this->adapter = new InMemory();
		$this->registry = new CollectorRegistry($this->adapter);
	}

	public function registry() {
		return $this->registry;
	}

	public function getCounter(string $name, string $help, array $labels = []) {
		return $this->registry->getOrRegisterCounter('sccuot_ng', $name, $help, $labels);
	}

	public function getGauge(string $name, string $help, array $labels = []) {
		return $this->registry->getOrRegisterGauge('sccuot_ng', $name, $help, $labels);
	}

	public function getHistogram(string $name, string $help, $minValue, $maxValue, int $binCount, bool $floatValues = false, array $labels = []) {
		$bins = new HistogramBins($minValue, $maxValue, $binCount, $floatValues);
		return $this->registry->getOrRegisterHistogram('sccuot_ng', $name, $help, $labels, $bins->getBins());
	}
}
