<?php

namespace OCA\SccuotNG\Stats\Collector;

use Exception;

use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Util\OutputProxy;

use OCP\IDBConnection;

abstract class BaseCollector implements ICollector {
	const RETRY_TIMES = 3;

	public function collect(IDBConnection $db, int $timestamp, int $chunkSize, ConfigService $config) {
		$data = null;
		$count = self::RETRY_TIMES;
		for ($i = 1; $i <= $count; ++$i) {
			OutputProxy::print("  Collecting {$this->dataName()}... ");
			try {
				$startTime = microtime(true);
				$data = $this->collectData($db, $timestamp, $chunkSize, $config);
				$timeElapsed = number_format(microtime(true) - $startTime, 3);
				OutputProxy::println("done ({$timeElapsed}s)");
				break;
			} catch (Exception $e) {
				$data = null;
				OutputProxy::println("failed ({$e->getMessage()})");
				if ($i < $count) {
					OutputProxy::println("    Attempt {$i} of {$count} failed, retrying...");
					$chunkSize /= 2;    // Halve the chunk size to reduce likelihood of errors
				} else {
					OutputProxy::println("    Attempt {$i} of {$count} failed, aborting...");
					throw $e;
				}
			}
		}
		return $data;
	}

    public function dataName() {
        // Get the class name, remove 'Collector' from the end and split the result by capital letters
        $tokens = explode('\\', get_class($this));
        $pieces = preg_split('/(?=[A-Z])/', end($tokens));
        array_pop($pieces);
        return join(' ', array_filter(array_map('strtolower', $pieces)));
    }

	protected function collectData(IDBConnection $db, int $timestamp, int $chunkSize, ConfigService $config) {
		return null;
	}
}
