<?php

namespace OCA\SccuotNG\Stats\Collector;

use OCA\SccuotNG\Db\OC\FilecacheMapper;
use OCA\SccuotNG\Service\ConfigService;

use OCP\IDBConnection;

class FileTypesCountsCollector extends BaseCollector {
    protected function collectData(IDBConnection $db, int $timestamp, int $chunkSize, ConfigService $config) {
        $fileCounts = [];
        $mapper = new FilecacheMapper($db, $chunkSize, $config->getSnapshotFiletypesFilterClosedAccounts() ? '1' : 0);
	    $counts = $mapper->queryFiletypesCounts();
	    foreach ($config->getSnapshotFileTypes()->groups() as $groupName => $group) {
		    if (!$group->isCollectEnabled()) {
			    continue;
		    }

		    $fileTypes = $group->getFileTypes();
		    if (count($fileTypes) > 0) {
				$count = $size = 0;
				foreach ($fileTypes as $fileType) {
					if (array_key_exists($fileType, $counts)) {
						$count += $counts[$fileType]['count'];
						$size += $counts[$fileType]['size'];
					}
				}
			    $fileCounts[$groupName] = [
				    'file_types' => $fileTypes,
				    'count' => $count,
				    'size' => $size,
			    ];
		    }
	    }
        return $fileCounts;
    }
}
