<?php

namespace OCA\SccuotNG\Stats\Collector;

use OCA\SccuotNG\Db\OC\PreferencesMapper;
use OCA\SccuotNG\Db\OC\StoragesMapper;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Util\FileSize;

use OCP\IDBConnection;

class UsersQuotaCollector extends BaseCollector {
    protected function collectData(IDBConnection $db, int $timestamp, int $chunkSize, ConfigService $config) {
        $accMapper = new PreferencesMapper($db, $chunkSize);
		$storeMapper = new StoragesMapper($db, $chunkSize);
		$userQuotas = $accMapper->queryUserQuotas($this->getDefaultQuotas($config));
		$quotaUsages = [];
		foreach ($userQuotas as $user => $quota) {
			if ($quota === 0) {
				continue;
			}
			$usedSpace = $storeMapper->queryUsedStorage($user);
			$quotaUsages[] = $usedSpace / $quota;
		}
        sort($quotaUsages);
        return $quotaUsages;
    }

	private function getDefaultQuotas($config) {
		$defaultOCQuota = FileSize::ParseQuotaString($config->config()->getAppValue('files', 'default_quota'));
		$defaultLDAPQuota = FileSize::ParseQuotaString($config->config()->getAppValue('user_ldap', 'ldap_quota_def'));
		return [
			"OC\\User\\Database" => $defaultOCQuota,
			"OCA\\User_LDAP" => $defaultLDAPQuota,
		];
	}
}
