<?php

namespace OCA\SccuotNG\Stats\Value;

use OCA\SccuotNG\Stats\Collector\{
    ICollector,
    FileTypesCountsCollector
};
use OCA\SccuotNG\Db\Snapshot;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\MetricsService;

class FileTypesCountsValue extends BaseValue {
    public function setData($data) {
        $this->reset();
        if ($data != null) {
            if (is_array($data)) {
                $this->value = $data;
            } else if (is_string($data)) {
                $this->value = json_decode($data, true);
            } else {
                $this->throwTypeError($data);
            }
        }
    }

    public function createCollector(): ICollector {
        return new FileTypesCountsCollector();
    }

	public function expose(Snapshot $snapshot, MetricsService $metrics, ConfigService $config) {
		foreach ($this->value as $k => $v) {
			$metrics->getGauge('file_types_count', 'Number of files in a file types group', ['group_name', 'file_types'])
				->set($v['count'], [$k, implode(',', $v['file_types'])]);

			// Size is only available in snapshots >= v2
			if ($snapshot->qualifies(Snapshot::SNAPSHOT_VERSION_2)) {
				$metrics->getGauge('file_types_size', 'Size of files in a file types group', ['group_name', 'file_types'])
					->set($v['size'], [$k, implode(',', $v['file_types'])]);
			}
		}
	}

	private function reset() {
        $this->value = [];
    }
}
