<?php

namespace OCA\SccuotNG\Stats\Value;

use OCA\SccuotNG\Stats\Collector\{
    ICollector,
    FilesCountCollector
};
use OCA\SccuotNG\Db\Snapshot;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\MetricsService;

class FilesCountValue extends BaseValue {
	const TOTAL_COUNT = 'total';
	const OBSOLETE_COUNT = 'obsolete';

    public function setData($data) {
	    $this->reset();
	    if ($data != null) {
		    if (is_array($data)) {
			    $this->value = $data;
		    } else if (is_string($data)) {
			    $this->value = json_decode($data, true);
		    } else {
			    $this->throwTypeError($data);
		    }
	    }
    }

    public function createCollector(): ICollector {
        return new FilesCountCollector();
    }

	public function expose(Snapshot $snapshot, MetricsService $metrics, ConfigService $config) {
		$metrics->getGauge('files_count_total', 'Total number of files')->set($this->value[self::TOTAL_COUNT]);
		$metrics->getGauge('files_count_obsolete', 'Total number of obsolete files')->set($this->value[self::OBSOLETE_COUNT]);
	}

    private function reset() {
        $this->value = [
			self::TOTAL_COUNT => 0,
	        self::OBSOLETE_COUNT => 0,
        ];
    }
}
