<?php

namespace OCA\SccuotNG\Stats\Value;

use OCA\SccuotNG\Stats\Collector\{
    ICollector,
    FilesSizeCollector
};
use OCA\SccuotNG\Db\Snapshot;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\MetricsService;

class FilesSizeValue extends BaseValue {
	const TOTAL_SIZE = 'total';
	const OBSOLETE_SIZE = 'obsolete';

    public function setData($data) {
	    $this->reset();
	    if ($data != null) {
		    if (is_array($data)) {
			    $this->value = $data;
		    } else if (is_string($data)) {
			    $this->value = json_decode($data, true);
		    } else {
			    $this->throwTypeError($data);
		    }
	    }
    }

    public function createCollector(): ICollector {
        return new FilesSizeCollector();
    }

	public function expose(Snapshot $snapshot, MetricsService $metrics, ConfigService $config) {
		$metrics->getGauge('files_size_total', 'Total size (in bytes) of files')->set($this->value[self::TOTAL_SIZE]);
		$metrics->getGauge('files_size_obsolete', 'Total size (in bytes) of obsolete files')->set($this->value[self::OBSOLETE_SIZE]);
	}

    private function reset() {
	    $this->value = [
		    self::TOTAL_SIZE => 0,
		    self::OBSOLETE_SIZE => 0,
	    ];
    }
}
