<?php

namespace OCA\SccuotNG\Stats\Value;

use OCA\SccuotNG\Stats\Collector\{
    ICollector,
    SharesCountCollector
};
use OCA\SccuotNG\Db\Snapshot;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\MetricsService;

class SharesCountValue extends BaseValue {
    const TOTAL_COUNT = 'total';
    const FILES_COUNT = 'files';
    const FOLDERS_COUNT = 'folders';
	const PUBLIC_LINKS_COUNT = 'public_links';
	const EXTERNAL_COUNT = 'external';

    public function setData($data) {
        $this->reset();
        if ($data != null) {
            if (is_array($data)) {
                $this->value = $data;
            } else if (is_string($data)) {
                $this->value = json_decode($data, true);
            } else {
                $this->throwTypeError($data);
            }
        }
    }

    public function createCollector(): ICollector {
        return new SharesCountCollector();
    }

	public function expose(Snapshot $snapshot, MetricsService $metrics, ConfigService $config) {
		$metrics->getGauge('shares_count_total', 'Total shares count')->set($this->value[self::TOTAL_COUNT]);
		$metrics->getGauge('shares_count_files', 'Shared files count')->set($this->value[self::FILES_COUNT]);
		$metrics->getGauge('shares_count_folders', 'Shared folders count')->set($this->value[self::FOLDERS_COUNT]);
		$metrics->getGauge('shares_count_external', 'External shares count')->set($this->value[self::EXTERNAL_COUNT]);

		// Public links count is only available in snapshots >= v3
		if ($snapshot->qualifies(Snapshot::SNAPSHOT_VERSION_3)) {
			$metrics->getGauge('shares_count_public_links', 'Public links count')->set($this->value[self::PUBLIC_LINKS_COUNT]);
		}
	}

	private function reset() {
        $this->value = [
            self::TOTAL_COUNT => 0,
            self::FILES_COUNT => 0,
            self::FOLDERS_COUNT => 0,
	        self::PUBLIC_LINKS_COUNT => 0,
	        self::EXTERNAL_COUNT => 0,
        ];
    }
}
