<?php

namespace OCA\SccuotNG\Stats\Value;

use OCA\SccuotNG\Stats\Collector\{
    ICollector,
    UsersCountCollector
};
use OCA\SccuotNG\Db\Snapshot;
use OCA\SccuotNG\Misc\TimePeriods;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\MetricsService;

class UsersCountValue extends BaseValue {
    const TOTAL_COUNT = 'total';
	const CLOSED_COUNT = 'closed';

    public function setData($data) {
        $this->reset();
        if ($data != null) {
            if (is_array($data)) {
                $this->value = $data;
            } else if (is_string($data)) {
                $this->value = json_decode($data, true);
            } else {
                $this->throwTypeError($data);
            }
        }
    }

    public function createCollector(): ICollector {
        return new UsersCountCollector();
    }

	public function expose(Snapshot $snapshot, MetricsService $metrics, ConfigService $config) {
		foreach ($this->value as $k => $v) {
			$metrics->getGauge("users_count_{$k}", "Users count ({$k})")->set($v);
		}
	}

	private function reset() {
        $this->value = [self::TOTAL_COUNT => 0, self::CLOSED_COUNT => 0];
        foreach (TimePeriods::periods() as $k => $period) {
            $this->value[$k] = 0;
        }
    }
}
