<?php

namespace OCA\SccuotNG\Stats\Value;

use OCA\SccuotNG\Stats\Collector\{
    ICollector,
    UsersQuotaCollector
};
use OCA\SccuotNG\Db\Snapshot;
use OCA\SccuotNG\Service\ConfigService;
use OCA\SccuotNG\Service\MetricsService;

class UsersQuotaValue extends BaseValue {
	const HISTOGRAM_BIN_COUNT = 32;

    public function setData($data) {
        $this->reset();
        if ($data != null) {
            if (is_array($data)) {
                $this->value = $data;
            } else if (is_string($data)) {
                $this->value = json_decode($data);
            } else {
                $this->throwTypeError($data);
            }
        }
    }

    public function createCollector(): ICollector {
        return new UsersQuotaCollector();
    }

	public function expose(Snapshot $snapshot, MetricsService $metrics, ConfigService $config) {
		if (count($this->value) == 0) {
			// No data, no histogram
			return;
		}

		$minValue = $this->value[0];
		$maxValue = $this->value[array_key_last(($this->value))];
		$histogram = $metrics->getHistogram('users_quota', 'Users quota usage histogram', $minValue, $maxValue, self::HISTOGRAM_BIN_COUNT, true);
		foreach ($this->value as $v) {
			$histogram->observe($v);
		}
	}

    private function reset() {
        $this->value = [];
    }
}
